import Arrangement from "./arrangement.ts"

export default () => {
  const arrangement = new Arrangement()
  /**
   * 2025
   * https://www.gov.cn/zhengce/zhengceku/202411/content_6986383.htm
   * 一、元旦：1月1日（周三）放假1天，不调休。
   * 二、春节：1月28日（农历除夕、周二）至2月4日（农历正月初七、周二）放假调休，共8天。1月26日（周日）、2月8日（周六）上班。
   * 三、清明节：4月4日（周五）至6日（周日）放假，共3天。
   * 四、劳动节：5月1日（周四）至5日（周一）放假调休，共5天。4月27日（周日）上班。
   * 五、端午节：5月31日（周六）至6月2日（周一）放假，共3天。
   * 六、国庆节、中秋节：10月1日（周三）至8日（周三）放假调休，共8天。9月28日（周日）、10月11日（周六）上班。
   */
  arrangement.y(2025)
    .ny().r(1, 1)
    .s().r(1, 28).to(2, 4).w(1, 26).w(2, 8).i(2, 3).i(2, 4)
    .t().r(4, 4).to(4, 6)
    .l().r(5, 1).to(5, 5).w(4, 27).i(5, 5)
    .d().r(5, 31).to(6, 2)
    .n().r(10, 1).to(10, 8).w(9, 28).w(10, 11).i(10, 7).i(10, 8)
    .m().r(10, 6)

  /**
   * 2024
   * https://www.gov.cn/zhengce/content/202310/content_6911527.htm
   * 一、元旦：1月1日放假，与周末连休。
   * 二、春节：2月10日至17日放假调休，共8天。2月4日（星期日）、2月18日（星期日）上班。
   * 三、清明节：4月4日至6日放假调休，共3天。4月7日（星期日）上班。
   * 四、劳动节：5月1日至5日放假调休，共5天。4月28日（星期日）、5月11日（星期六）上班。
   * 五、端午节：6月10日放假，与周末连休。
   * 六、中秋节：9月15日至17日放假调休，共3天。9月14日（星期六）上班。
   * 七、国庆节：10月1日至7日放假调休，共7天。9月29日（星期日）、10月12日（星期六）上班。
   */
  arrangement.y(2024)
    .ny().r(1, 1)
    .s().r(2, 10).to(2, 17).w(2, 4).w(2, 18).i(2, 15).to(2, 16)
    .t().r(4, 4).to(4, 6).w(4, 7).i(4, 5)
    .l().r(5, 1).to(5, 5).w(4, 28).w(5, 11).i(5, 2).to(5, 3)
    .d().r(6, 10)
    .m().r(9, 15).to(9, 17).w(9, 14).i(9, 16)
    .n().r(10, 1).to(10, 7).w(9, 29).w(10, 12).i(10, 4).i(10, 7)
  
  /**
  * 2023
  * http://www.gov.cn/zhengce/content/2022-12/08/content_5730844.htm
  * 一、元旦：2022年12月31日至2023年1月2日放假调休，共3天。
  * 二、春节：1月21日至27日放假调休，共7天。1月28日（星期六）、1月29日（星期日）上班。
  * 三、清明节：4月5日放假，共1天。
  * 四、劳动节：4月29日至5月3日放假调休，共5天。4月23日（星期日）、5月6日（星期六）上班。
  * 五、端午节：6月22日至24日放假调休，共3天。6月25日（星期日）上班。
  * 六、中秋节、国庆节：9月29日至10月6日放假调休，共8天。10月7日（星期六）、10月8日（星期日）上班。
  */
  arrangement.y(2023)
    .ny().r(1, 1).to(1, 2)
    .s().r(1, 21).to(1, 27).w(1, 28).to(1, 29).i(1, 26).to(1, 27)
    .t().r(4, 5)
    .l().r(4, 29).to(5, 3).w(4, 23).w(5, 6).i(5, 2).to(5, 3)
    .d().r(6, 22).to(6, 24).w(6, 25).i(6, 23)
    .m().r(9, 29)
    .n().r(9, 30).to(10, 6).w(10, 7).to(10, 8).i(10, 5).to(10, 6)
  
  /**
  * 2022
  * http://www.gov.cn/zhengce/content/2021-10/25/content_5644835.htm
  * 一、元旦：2022年1月1日至3日放假，共3天。
  * 二、春节：1月31日至2月6日放假调休，共7天。1月29日（星期六）、1月30日（星期日）上班。
  * 三、清明节：4月3日至5日放假调休，共3天。4月2日（星期六）上班。
  * 四、劳动节：4月30日至5月4日放假调休，共5天。4月24日（星期日）、5月7日（星期六）上班。
  * 五、端午节：6月3日至5日放假，共3天。
  * 六、中秋节：9月10日至12日放假，共3天。
  * 七、国庆节：10月1日至7日放假调休，共7天。10月8日（星期六）、10月9日（星期日）上班。
  */
  arrangement.y(2022)
    .ny().r(1, 1).to(1, 3)
    .s().r(1, 31).to(2, 6).w(1, 29).w(1, 30).i(2, 3).to(2, 4)
    .t().r(4, 3).to(4, 5).w(4, 2).i(4, 4)
    .l().r(4, 30).to(5, 4).w(4, 24).w(5, 7).i(5, 3).to(5, 4)
    .d().r(6, 3).to(6, 5)
    .m().r(9, 10).to(9, 12)
    .n().r(10, 1).to(10, 7).w(10, 8).w(10, 9).i(10, 6).to(10, 7)
    .ny().r(12, 31)
  
  /**
  * 2021
  * http://www.gov.cn/zhengce/content/2020-11/25/content_5564127.htm
  * 一、元旦：2021年1月1日至3日放假，共3天。
  * 二、春节：2月11日至17日放假调休，共7天。2月7日（星期日）、2月20日（星期六）上班。
  * 三、清明节：4月3日至5日放假调休，共3天。
  * 四、劳动节：5月1日至5日放假调休，共5天。4月25日（星期日）、5月8日（星期六）上班。
  * 五、端午节：6月12日至14日放假，共3天。
  * 六、中秋节：9月19日至21日放假调休，共3天。9月18日（星期六）上班。
  * 七、国庆节：10月1日至7日放假调休，共7天。9月26日（星期日）、10月9日（星期六）上班。
  */
  arrangement.y(2021)
    .ny().r(1, 1).to(1, 3)
    .s().r(2, 11).to(2, 17).w(2, 7).w(2, 20).i(2, 16).to(2, 17)
    .t().r(4, 3).to(4, 5)
    .l().r(5, 1).to(5, 5).w(4, 25).w(5, 8).i(5, 4).to(5, 5)
    .d().r(6, 12).to(6, 14)
    .m().r(9, 19).to(9, 21).w(9, 18).i(9, 20)
    .n().r(10, 1).to(10, 7).w(9, 26).w(10, 9).i(10, 6).to(10, 7)
  
  /**
  * 2020
  * http://www.gov.cn/zhengce/content/2019-11/21/content_5454164.htm
  * 一、元旦：2020年1月1日放假，共1天。
  * 二、春节：1月24日至30日放假调休，共7天。1月19日（星期日）、2月1日（星期六）上班。
  * 三、清明节：4月4日至6日放假调休，共3天。
  * 四、劳动节：5月1日至5日放假调休，共5天。4月26日（星期日）、5月9日（星期六）上班。
  * 五、端午节：6月25日至27日放假调休，共3天。6月28日（星期日）上班。
  * 六、国庆节、中秋节：10月1日至8日放假调休，共8天。9月27日（星期日）、10月10日（星期六）上班。
  * 
  * http://www.gov.cn/zhengce/content/2020-01/27/content_5472352.htm
  * 延长2020年春节假期至2月2日（农历正月初九，星期日），2月3日（星期一）起正常上班。
  */
  arrangement.y(2020)
    .ny().r(1, 1)
    .s().r(1, 24).to(2, 2).w(1, 19).i(1, 29)
    .t().r(4, 4).to(4, 6)
    .l().r(5, 1).to(5, 5).w(4, 26).w(5, 9).i(5, 4).to(5, 5)
    .d().r(6, 25).to(6, 27).w(6, 28).i(6, 26)
    .n().r(10, 1).to(10, 8).w(9, 27).w(10, 10).i(10, 7).to(10, 8)
  
  /**
  * 2019
  * http://www.gov.cn/xinwen/2018-12/06/content_5346287.htm
  * 一、元旦：12月30日至1月1日放假，共3天。 12月29日（星期六）上班。
  * 二、春节：2月4日至10日放假调休，共7天。2月2日（星期六）、2月3日（星期天）上班。
  * 三、清明节：4月5日放假，与周末连休。
  * 四、劳动节：5月1日放假，共1天。
  * 五、端午节：6月7日放假，与周末连休。
  * 六、中秋节：9月13日放假，与周末连休。
  * 七、国庆节：10月1日至7日放假调休，共7天。9月29日（星期天）、10月12日（周六）上班。
  * http://www.gov.cn/zhengce/content/2019-03/22/content_5375877.htm
  * 经国务院批准，现将调整2019年劳动节放假安排通知如下。
  * 2019年5月1日至4日放假调休，共4天。4月28日（星期日）、5月5日（星期日）上班。
  */
  arrangement.y(2019)
    .ny().r(1, 1)
    .s().r(2, 4).to(2, 10).w(2, 2).to(2, 3).i(2, 4).i(2, 8)
    .t().r(4, 5).to(4, 7)
    .l().r(5, 1).to(5, 4).w(4, 28).w(5, 5).i(5, 2).i(5, 3)
    .d().r(6, 7).to(6, 9)
    .m().r(9, 13).to(9, 15)
    .n().r(10, 1).to(10, 7).w(9, 29).w(10, 12).i(10, 4).i(10, 7)
  
  /**
  * 2018
  * http://www.gov.cn/zhengce/content/2017-11/30/content_5243579.htm
  * 一、元旦：1月1日放假，与周末连休。
  * 二、春节：2月15日至21日放假调休，共7天。2月11日（星期日）、2月24日（星期六）上班。
  * 三、清明节：4月5日至7日放假调休，共3天。4月8日（星期日）上班。
  * 四、劳动节：4月29日至5月1日放假调休，共3天。4月28日（星期六）上班。
  * 五、端午节：6月18日放假，与周末连休。
  * 六、中秋节：9月24日放假，与周末连休。
  * 七、国庆节：10月1日至7日放假调休，共7天。9月29日（星期六）、9月30日（星期日）上班。
  */
  arrangement.y(2018)
    .ny().r(1, 1)
    .s().r(2, 15).to(2, 21).w(2, 11).w(2, 24).i(2, 19).to(2, 21)
    .t().r(4, 5).to(4, 7).w(4, 8).i(4, 6)
    .l().r(4, 29).to(5, 1).w(4, 28).i(4, 30)
    .d().r(6, 18)
    .n().r(10, 1).to(10, 7).w(9, 29).to(9, 30).i(10, 4).to(10, 5)
    .m().r(9, 24)
    .ny().r(12, 30).to(12, 31).w(12, 29).i(12, 31)
  
  /**
  * 2017
  * http://www.gov.cn/zhengce/content/2016-12/01/content_5141603.htm
  * 一、元旦：1月1日放假，1月2日（星期一）补休。
  * 二、春节：1月27日至2月2日放假调休，共7天。1月22日（星期日）、2月4日（星期六）上班。
  * 三、清明节：4月2日至4日放假调休，共3天。4月1日（星期六）上班。
  * 四、劳动节：5月1日放假，与周末连休。
  * 五、端午节：5月28日至30日放假调休，共3天。5月27日（星期六）上班。
  * 六、中秋节、国庆节：10月1日至8日放假调休，共8天。9月30日（星期六）上班。
  */
  arrangement.y(2017)
    .ny().r(1, 1).to(1, 2)
    .s().r(1, 27).to(2, 2).w(1, 22).w(2, 4).i(2, 1).to(2, 2)
    .t().r(4, 2).to(4, 4).w(4, 1).i(4, 3)
    .l().r(5, 1)
    .d().r(5, 28).to(5, 30).w(5, 27).i(5, 29)
    .n().r(10, 1).to(10, 8).w(9, 30).i(10, 6)
    .m().r(10, 4)  // 国庆中秋相连，经查证10月4日为中秋
  
  /**
  * 2016
  * http://www.gov.cn/zhengce/content/2015-12/10/content_10394.htm
  * 一、元旦：1月1日放假，与周末连休。
  * 二、春节：2月7日至13日放假调休，共7天。2月6日（星期六）、2月14日（星期日）上班。
  * 三、清明节：4月4日放假，与周末连休。
  * 四、劳动节：5月1日放假，5月2日（星期一）补休。
  * 五、端午节：6月9日至11日放假调休，共3天。6月12日（星期日）上班。
  * 六、中秋节：9月15日至17日放假调休，共3天。9月18日（星期日）上班。
  * 七、国庆节：10月1日至7日放假调休，共7天。10月8日（星期六）、10月9日（星期日）上班。
  */
  arrangement.y(2016)
    .ny().r(1, 1)
    .s().r(2, 7).to(2, 13).w(2, 6).w(2, 14).i(2, 11).to(2, 12)
    .t().r(4, 4)
    .l().r(5, 1).to(5, 2)
    .d().r(6, 9).to(6, 11).w(6, 12).i(6, 10)
    .m().r(9, 15).to(9, 17).w(9, 18).i(9, 16)
    .n().r(10, 1).to(10, 7).w(10, 8).to(10, 9).i(10, 6).to(10, 7)
  
  /**
  * 2015
  * http://www.gov.cn/zhengce/content/2014-12/16/content_9302.htm
  * 一、元旦：1月1日至3日放假调休，共3天。1月4日（星期日）上班。
  * 二、春节：2月18日至24日放假调休，共7天。2月15日（星期日）、2月28日（星期六）上班。
  * 三、清明节：4月5日放假，4月6日（星期一）补休。
  * 四、劳动节：5月1日放假，与周末连休。
  * 五、端午节：6月20日放假，6月22日（星期一）补休。
  * 六、中秋节：9月27日放假。
  * 七、国庆节：10月1日至7日放假调休，共7天。10月10日（星期六）上班。
  * 
  *   注意：参见《国务院关于中国人民抗日战争暨世界反法西斯战争胜利70周年纪念日调休放假的通知》
  *   http://www.gov.cn/zhengce/content/2015-05/13/content_9742.htm
  *   额外的放假安排如下：
  *   9月3日至5日调休放假，共3天。其中9月3日（星期四）放假，9月4日（星期五）调休，9月6日（星期日）上班。
  */
  arrangement.y(2015)
    .ny().r(1, 1).to(1, 3).w(1, 4).i(1, 2)
    .s().r(2, 18).to(2, 24).w(2, 15).w(2, 28).i(2, 23).to(2, 24)
    .t().r(4, 5).to(4, 6)
    .l().r(5, 1)
    .d().r(6, 20).r(6, 22)
    .m().r(9, 27)
    .n().r(10, 1).to(10, 7).w(10, 10).i(10, 7)
    .a().r(9, 3).to(9, 4).w(9, 6).i(9, 4)
  
  /**
  * 2014
  * http://www.gov.cn/zwgk/2013-12/11/content_2546204.htm
  * 一、元旦：1月1日放假1天。
  * 二、春节：1月31日至2月6日放假调休，共7天。1月26日（星期日）、2月8日（星期六）上班。
  * 三、清明节：4月5日放假，4月7日（星期一）补休。
  * 四、劳动节：5月1日至3日放假调休，共3天。5月4日（星期日）上班。
  * 五、端午节：6月2日放假，与周末连休。
  * 六、中秋节：9月8日放假，与周末连休。
  * 七、国庆节：10月1日至7日放假调休，共7天。9月28日（星期日）、10月11日（星期六）上班。
  */
  arrangement.y(2014)
    .ny().r(1, 1)
    .s().r(1, 31).to(2, 6).w(1, 26).w(2, 8).i(2, 5).to(2, 6)
    .t().r(4, 5).to(4, 7)
    .l().r(5, 1).to(5, 3).w(5, 4).i(5, 2)
    .d().r(6, 2)
    .m().r(9, 8)
    .n().r(10, 1).to(10, 7).w(9, 28).w(10, 11).i(10, 6).to(10, 7)
  
  /**
  * 2013
  * http://www.gov.cn/zwgk/2012-12/10/content_2286598.htm
  * 一、元旦：1月1日至3日放假调休，共3天。1月5日（星期六）、1月6日（星期日）上班。
  * 二、春节：2月9日至15日放假调休，共7天。2月16日（星期六）、2月17日（星期日）上班。
  * 三、清明节：4月4日至6日放假调休，共3天。4月7日（星期日）上班。
  * 四、劳动节：4月29日至5月1日放假调休，共3天。4月27日（星期六）、4月28日（星期日）上班。
  * 五、端午节：6月10日至12日放假调休，共3天。6月8日（星期六）、6月9日（星期日）上班。
  * 六、中秋节：9月19日至21日放假调休，共3天。9月22日（星期日）上班。
  * 七、国庆节：10月1日至7日放假调休，共7天。9月29日（星期日）、10月12日（星期六）上班。
  */
  arrangement.y(2013)
    .ny().r(1, 1).to(1, 3).w(1, 5).to(1, 6).i(1, 2).to(1, 3)
    .s().r(2, 9).to(2, 15).w(2, 16).to(2, 17).i(2, 14).to(2, 15)
    .t().r(4, 4).to(4, 6).w(4, 7).i(4, 5)
    .l().r(4, 29).to(5, 1).w(4, 27).to(4, 28).i(4, 29).to(4, 30)
    .d().r(6, 10).to(6, 12).w(6, 8).to(6, 9).i(6, 10).to(6, 11)
    .m().r(9, 19).to(9, 21).w(9, 22).i(9, 20)
    .n().r(10, 1).to(10, 7).w(9, 29).w(10, 12).i(10, 4).i(10, 7)
  
  /**
  * 2012
  * http://www.gov.cn/zwgk/2011-12/06/content_2012097.htm
  * 一、元旦：2012年1月1日至3日放假调休，共3天。2011年12月31日（星期六）上班。
  * 二、春节：1月22日至28日放假调休，共7天。1月21日（星期六）、1月29日（星期日）上班。
  * 三、清明节：4月2日至4日放假调休，共3天。3月31日（星期六）、4月1日（星期日）上班。
  * 四、劳动节：4月29日至5月1日放假调休，共3天。4月28日（星期六）上班。
  * 五、端午节：6月22日至24日放假公休，共3天。
  * 六、中秋节、国庆节：9月30日至10月7日放假调休，共8天。9月29日（星期六）上班。
  * 
  *   注意：今年元旦特殊处理，去年上班 Σ( ° △ °|||)︴
  */
  arrangement.y(2012)
    .ny().r(1, 1).to(1, 3).i(1, 3)
    .s().r(1, 22).to(1, 28).w(1, 21).w(1, 29).i(1, 26).to(1, 27)
    .t().r(4, 2).to(4, 4).w(3, 31).w(4, 1).i(4, 2).to(4, 3)
    .l().r(4, 29).to(5, 1).w(4, 28).i(4, 30)
    .d().r(6, 22).r(6, 24)
    .m().r(9, 30)
    .n().r(10, 1).to(10, 7).w(9, 29).i(10, 5)
  
  /**
  * 2011
  * http://www.gov.cn/zwgk/2010-12/10/content_1762643.htm
  * 一、元旦：1月1日至3日放假公休，共3天。
  * 二、春节：2月2日（农历除夕）至8日放假调休，共7天。1月30日（星期日）、2月12日（星期六）上班。
  * 三、清明节：4月3日至5日放假调休，共3天。4月2日（星期六）上班。
  * 四、劳动节：4月30日至5月2日放假公休，共3天。
  * 五、端午节：6月4日至6日放假公休，共3天。
  * 六、中秋节：9月10日至12日放假公休，共3天。
  * 七、国庆节：10月1日至7日放假调休，共7天。10月8日（星期六）、10月9日（星期日）上班。
  * 
  *  注意：明年元旦特殊处理，放到今年上班了 Σ( ° △ °|||)︴
  */
  arrangement.y(2011)
    .ny().r(1, 1).to(1, 3)
    .s().r(2, 2).to(2, 8).w(1, 30).w(2, 12).i(2, 7).to(2, 8)
    .t().r(4, 3).to(4, 5).w(4, 2).i(4, 4)
    .l().r(4, 30).to(5, 2)
    .d().r(6, 4).r(6, 6)
    .m().r(9, 10).to(9, 12)
    .n().r(10, 1).to(10, 7).w(10, 8).to(10, 9).i(10, 6).to(10, 7)
    .ny().w(12, 31)
  
  /**
  * 2010
  * http://www.gov.cn/zwgk/2009-12/08/content_1482691.htm
  * 一、元旦：1月1日至3日放假公休，共3天。
  * 二、春节：2月13日至19日放假调休，共7天。2月20日（星期六）、21日（星期日）上班。
  * 三、清明节：4月3日至5日放假公休，共3天。
  * 四、劳动节：5月1日至3日放假公休，共3天。
  * 五、端午节：6月14日至16日放假调休，共3天。6月12日（星期六）、13日（星期日）上班。
  * 六、中秋节：9月22日至24日放假调休，共3天。9月19日（星期日）、25日（星期六）上班。
  * 七、国庆节：10月1日至7日放假调休，共7天。9月26日（星期日）、10月9日（星期六）上班。
  */
  arrangement.y(2010)
    .ny().r(1, 1).to(1, 3)
    .s().r(2, 13).to(2, 19).w(2, 20).to(2, 21).i(2, 18).to(2, 19)
    .t().r(4, 3).to(4, 5)
    .l().r(5, 1).to(5, 3)
    .d().r(6, 14).to(6, 16).w(6, 12).to(6, 13).i(6, 14).to(6, 15)
    .m().r(9, 22).to(9, 24).w(9, 19).w(9, 25).i(9, 23).to(9, 24)
    .n().r(10, 1).to(10, 7).w(9, 26).w(10, 9).i(10, 6).to(10, 7)
  
  /**
  * 2009
  *  http://www.gov.cn/zwgk/2008-12/10/content_1174014.htm
  * 一、元旦：1月1日至3日放假，共3天。
  * 其中，1月1日（星期四、新年）为法定节假日，1月3日（星期六）为公休日。
  * 1月4日（星期日）公休日调至1月2日（星期五）。
  * 1月4日（星期日）上班。
  * 二、春节：1月25日至31日放假，共7天。
  * 其中，1月25日（星期日、农历除夕）、1月26日（星期一、农历正月初一）、1月27日（星期二、农历正月初二）为法定节假日，1月31日（星期六）照常公休；1月25日（星期日）公休日调至1月28日（星期三），1月24日（星期六）、2月1
  * 日（星期日）两个公休日调至1月29日（星期四）、1月30日（星期五）。
  * 1月24日（星期六）、2月1日（星期日）上班。
  * 三、清明节：4月4日至6日放假，共3天。
  * 其中，4月4日（星期六、农历清明当日）为法定节假日，4月5日（星期日）照常公休。
  * 4月4日（星期六）公休日调至4月6日（星期一）。
  * 四、劳动节：5月1日至3日放假，共3天。
  * 其中，5月1日（星期五、“五一”国际劳动节）为法定节假日，5月2日（星期六）、5月3日（星期日）照常公休。
  * 五、端午节：5月28日至30日放假，共3天。
  * 其中，5月28日（星期四、农历端午当日）为法定节假日，5月30日（星期六）照常公休；5月31日（星期日）公休日调至5月29日（星期五）。
  * 5月31日（星期日）上班。
  * 六、国庆节、中秋节：10月1日至8日放假，共8天。
  * 其中，10月1日（星期四）、10月2日（星期五）、10月3日（星期六）为国庆节法定节假日，10月4日（星期日）照常公休；10月3日（星期六）公休日及中秋节分别调至10月5日（星期一）、10月6日（星期二），9月27日（星期日）、10
  * 月10日（星期六）公休日调至10月7日（星期三）、10月8日（星期四）。
  * 9月27日（星期日）、10月10日（星期六）上班。
  */
  arrangement.y(2009)
    .ny().r(1, 1).to(1, 3).w(1, 4).i(1, 2)
    .s().r(1, 25).to(1, 31).w(1, 24).w(2, 1).i(1, 29).to(1, 30)
    .t().r(4, 4).to(4, 6)
    .l().r(5, 1).to(5, 3)
    .d().r(5, 28).to(5, 30).w(5, 31).i(5, 29)
    .n().r(10, 1).to(10, 8).w(9, 27).w(10, 10).i(10, 7).to(10, 8)
    .m().r(10, 3)  // 国庆中秋相连，经查证10月3日为中秋
  
  /**
  * 2008
  *  http://www.gov.cn/zwgk/2007-12/18/content_837184.htm
  * 一、元旦：2007年12月30日—2008年1月1日放假，共3天。
  * 其中，1月1日（星期二）为法定节假日，12月30日（星期日）为公休日，12月29日（星期六）公休日调至12月31日（星期一），12月29日（星期六）上班。
  * 二、春节：2月6日—12日（农历除夕至正月初六）放假，共7天。
  * 其中，2月6日（除夕）、2月7日（春节）、2月8日（正月初二）为法定节假日，2月9日（星期六）、2月10日（星期日）照常公休，2月2日（星期六）、2月3日（星期日）两个公休日调至2月11日（星期一）、2月12日（星期二），2月2
  * 日（星期六）、2月3日（星期日）上班。
  * 三、清明节：4月4日—6日放假，共3天。
  * 其中，4月4日（清明节）为法定节假日，4月5日（星期六）、4月6日（星期日）照常公休。
  * 四、“五一”国际劳动节：5月1日—3日放假，共3天。
  * 其中，5月1日为法定节假日，5月3日（星期六）为公休日，5月4日（星期日）公休日调至5月2日（星期五），5月4日（星期日）上班。
  * 五、端午节：6月7日—9日放假，共3天。
  * 其中，6月7日（星期六）照常公休，6月8日（农历五月初五，端午节）为法定节假日，6月8日（星期日）公休日调至6月9日（星期一）。
  * 六、中秋节：9月13日—15日放假，共3天。
  * 其中，9月13日（星期六）为公休日，9月14日（农历八月十五，中秋节）为法定节假日，9月14日（星期日）公休日调至9月15日（星期一）。
  * 七、国庆节：9月29日—10月5日放假，共7天。
  * 其中，10月1日、2日、3日为法定节假日，9月27日（星期六）、9月28日（星期日）两个公休日调至9月29日（星期一）、30日（星期二），10月4日（星期六）、5日（星期日）照常公休。
  * 
  *   注意：今年元旦假期，去年年尾要上班。
  */
  arrangement.y(2008)
    .ny().r(1, 1)
    .s().r(2, 6).to(2, 12).w(2, 2).to(2, 3).i(2, 11).to(2, 12)
    .t().r(4, 4).to(4, 6)
    .l().r(5, 1).to(5, 3).w(5, 4).i(5, 2)
    .d().r(6, 7).to(6, 9)
    .m().r(9, 13).to(9, 15)
    .n().r(9, 29).to(10, 5).w(9, 27).to(9, 28).i(9, 29).to(9, 30)
  
  /**
  * 2007
  *  http://www.gov.cn/fwxx/sh/2006-12/18/content_471877.htm
  * 一、元旦： 1月1日－3日放假，共三天。
  * 其中1月1日为法定假日，将2006年12月30日（星期六）、31日（星期日）两个公休日分别调至2007年1月2日、3日，2006年12月30日（星期六）、12月31日（星期日）上班。
  * 二、春节：2月18日—24日（即农历初一至初七）放假，共7天。
  * 其中18日、19日、20日为法定假日，将17日（星期六）、18日（星期日）、25日（星期日）三个公休日分别调至21日（星期三）、22日（星期四）、23日（星期五）；24日（星期六）照常公休，17日、25日上班。
  * 三、“五一”：5月1日—7日放假，共7天。
  * 其中，1日、2日、3日为法定假日，将4月28日（星期六）、29日（星期日）两个公休日调至5月4日（星期五）、7日（星期一）；5月5日（星期六）、6日（星期日）照常公休，4月28日、29日上班。
  * 四、“十一”：10月1日—7日放假，共7天。
  * 其中，1日、2日、3日为法定假日，将9月29日（星期六）、30日（星期日）两个公休日调至10月4日（星期四）、5日（星期五）；10月6日（星期六）、7日（星期日）照常公休，9月29日、30日上班。
  * 
  *   注意：明年元旦假期，今年年尾会放假。今年元旦假期，去年年尾要上班。
  */
  arrangement.y(2007)
    .ny().r(1, 1).to(1, 3).i(1, 2).to(1, 3)
    .s().r(2, 18).to(2, 24).w(2, 17).w(2, 25).i(2, 22).to(2, 23)
    .l().r(5, 1).to(5, 7).w(4, 28).to(4, 29).i(5, 4).i(5, 7)
    .n().r(10, 1).to(10, 7).w(9, 29).to(9, 30).i(10, 4).to(10, 5)
    .ny().r(12, 30).to(12, 31).w(12, 29).i(12, 31)
  
  /**
  * 2006
  *  http://www.gov.cn/jrzg/2005-12/22/content_133837.htm
  * 一、元旦：1月1日—3日放假，共3天。
  * 其中1月1日为法定假日，将12月31日(星期六)、1月1日(星期日)两个公休日调至1月2日(星期一)、3日(星期二)，12月31日(星期六)上班。
  * 二、春节：1月29日—2月4日(即农历大年初一至初七)放假，共7天。
  * 其中，29日、30日、31日为法定假日，将1月28日(星期六)、29日(星期日)、2月5日(星期日)三个公休日调至2月1日(星期三)、2日(星期四)、3日(星期五)，2月4日(星期六)照常公休，1月28日、2月5日上班。
  * 三、“五一”：5月1日—7日放假，共7天。
  * 其中，1日、2日、3日为法定假日，将4月29日(星期六)、30日(星期日)两个公休日调至5月4日(星期四)、5日(星期五)，5月6日(星期六)、7日(星期日)照常公休，4月29日、30日上班。
  * 四、“十一”：10月1日—7日放假，共7天。
  * 其中，1日、2日、3日为法定假日，将9月30日(星期六)、10月1日(星期日)、8日(星期日)三个公休日调至10月4日(星期三)、5日(星期四)、6日(星期五)，10月7日(星期六)照常公休，9月30日、10月8日上班。
  * 
  *   注意：明年元旦假期，今年年尾要上班。今年元旦假期，去年年尾要上班。
  */
  arrangement.y(2006)
    .ny().r(1, 1).to(1, 3)
    .s().r(1, 29).to(2, 4).w(1, 28).w(2, 5).i(2, 2).to(2, 3)
    .l().r(5, 1).to(5, 7).w(4, 29).to(4, 30).i(5, 4).to(5, 5)
    .n().r(10, 1).to(10, 7).w(9, 30).w(10, 8).i(10, 5).to(10, 6)
    .ny().w(12, 30).to(12, 31)
  
  /**
  * 2005
  * https://zhidao.baidu.com/question/2299098.html
  * 国务院办公厅近日发出通知，2005年元旦、春节、“五一”、“十一”放假调休日期具体安排如下：
  * 一、元旦：1月1日～3日放假，共3天。其中1月1日为法定假日，将1月1日(星期六)公休日调至1月3日(星期一)，1月2日(星期日)照常公休。
  * 二、春节：2月9日～15日(农历大年初一至初七)放假，共7天。其中，9日、10日、11日为法定假日，
  * 2月12日(星期六)、13日(星期日)照常公休，将2月5日(星期六)、6日(星期日)两个公休日调至2月14日(星期一)、15日(星期二)，
  * 2月5日、6日上班。
  * 三、“五一”：5月1日～7日放假，共7天。其中，1日、2日、3日为法定假日，将4月30日(星期六)、5月1日(星期日)、8日(星期日)三个公休日
  * 调至5月4日(星期三)、5日(星期四)、6日(星期五)，5月7日(星期六)照常公休，4月30日、5月8日上班。
  * 四、“十一”：10月1日～7日放假，共7天。其中，1日、2日、3日为法定假日，将10月1日(星期六)、2日(星期日)两个公休日
  * 调至10月4日(星期二)、5日(星期三)，10月8日(星期六)、9日(星期日)两个公休日调至10月6日(星期四)、7日(星期五)，10月8日、9日上班。
  */
  arrangement.y(2005)
    .ny().r(1, 1).to(1, 3)
    .s().r(2, 9).to(2, 15).w(2, 5).to(2, 6).i(2, 14).to(2, 15)
    .l().r(5, 1).to(5, 7).w(4, 30).w(5, 8).i(5, 5).to(5, 6)
    .n().r(10, 1).to(10, 7).w(10, 8).to(10, 9).i(10, 6).to(10, 7)
  
  /**
  * 2004
  *  https://zh.wikisource.org/zh-hans/国务院办公厅关于2004年部分节假日安排的通知
  *  各省、自治区、直辖市人民政府，国务院各部委、各直属机构：
  *    为便于各地区、各部门及早合理安排节假日旅游、交通运输、生产经营等有关工作，经国务院批准，现将2004年
  *  元旦、春节、“五一”、“十一”放假调休日期具体安排通知如下：
  *  一、元旦：1月1日放假。
  *  二、春节：1月22日———28日（即农历大年初一至初七）放假，共7天。
  *    其中，22日、23日、24日为法定假日，1月25日（星期日）照常公休，将1月17日（星期六）、18日（星期日）、24日（星期六）三个公休日
  *    调至1月26日（星期一）、27日（星期二）、28日（星期三），1月17日、18日上班。
  *  三、“五一”：5月1日———7日放假，共7天。
  *    其中，1日、2日、3日为法定假日，将5月1日（星期六）、2日（星期日）两个公休日调至5月4日（星期二）、5日（星期三），
  *    5月8日（星期六）、5月9日（星期日）两个公休日调至5月6日（星期四）、7日（星期五），5月8日、9日上班。
  *  四、“十一”：10月1日———7日放假，共7天。
  *    其中，1日、2日、3日为法定假日，将10月2日（星期六）、3日（星期日）两个公休日调至10月4日（星期一）、5日（星期二），
  *    10月9日（星期六）、10日（星期日）两个公休日调至10月6日（星期三）、7日（星期四），10月9日、10日上班。
  */
  arrangement.y(2004)
    .ny().r(1, 1)
    .s().r(1, 22).to(1, 28).w(1, 17).to(1, 18).i(1, 27).to(1, 28)
    .l().r(5, 1).to(5, 7).w(5, 8).to(5, 9).i(5, 6).to(5, 7)
    .n().r(10, 1).to(10, 7).w(10, 9).to(10, 10).i(10, 6).to(10, 7)
  
  /**
  * 注：2003年及以前的安排就很凌乱了（其实06/07两年也是叫“部分节假日安排”）
  * 假如之后想要加的话可以参考以下地址：
  * 2003: https://zh.wikisource.org/zh-hans/国务院办公厅关于2003年部分节假日休息安排的通知
  * 2002: https://zh.wikisource.org/zh-hans/国务院办公厅关于2002年部分节假日休息安排的通知
  * 2001: https://zh.wikisource.org/zh-hans/国务院办公厅关于2001年春节、“五一”、“十一”放假安排的通知
  */

  return {
    holidays: arrangement.holidays,
    workdays: arrangement.workdays,
    inLieuDays: arrangement.inLieuDays,
  }
}
